@@ -12,6 +12,11 @@ use vars qw($VERSION);
 sub new {
     my ($cls, $scaffold, $params) = @_;
     my $self = bless {};
+    my @scfld = @$scaffold;
+    shift @scfld;
+    my @fields;
+    map { push @fields, $_ unless !$_ || ref($_) || m{^#} } @scfld;
+    $self->{'fieldsCaptured'} = \@fields;
     $self->{'fieldsDiscovered'} = ['name','content'];
     return $self;
 }
@@ -21,8 +26,15 @@ sub scrape {
     
     my ($sub_string, $attributes) = $TidyXML->getMarkedTextAndAttributes('TR');
     return undef unless defined($sub_string);
+    
+    my @ary = @$scaffold;
+    shift @ary;
+    my $fldnam = shift @ary;
+    if ( $fldnam && (ref($fldnam) ne 'ARRAY') ) {
+        $hit->plug_elem($fldnam, ${$TidyXML->asString()}, $TidyXML);
+    }
 
-    return ($$scaffold[1], $sub_string, $attributes);
+    return ($self->_next_scaffold($scaffold), $sub_string, $attributes);
 }
 
 
